# GDPlib

We envision GDPlib as an open library of GDP models to provide examples for prospective modelers, and to provide a benchmarking set for algorithm developers.
We invite contributions to this library from the community, provided under the same BSD-3-clause or compatible license.

## Installation

GDPlib is an installable model library in Python.
To install GDPlib, you can use:

`pip install gdplib`

To update GDPlib:

`pip install --upgrade gdplib`

For a developer install, please clone this repository, activate the correct python environment, and run `python setup.py develop` on the `setup.py` file in this directory.

## Model descriptions

Details for each model are given in a separate README.md file in each directory.
